@@ -46,14 +46,14 @@ class ZeroShotClassifierParameters(AnnotatorParameters):
         None,
         description="""Which [Transformers model)(
                             https://huggingface.co/models?pipeline_tag=zero-shot-classification) fine-tuned
-                            for Zero-shot classification to use.""",
+                            for Zero-shot classification to use.""", extra="advanced"
     )
     processing_unit: ProcessingUnit = Field(
         ProcessingUnit.document,
         description="""The processing unit to apply the classification in the input
                                             documents, can be one of:<br/>
                                             <li>`document`
-                                            <li>`segment`""",
+                                            <li>`segment`""", extra="advanced"
     )
     candidate_labels: Dict[str, str] = Field(
         None,
@@ -62,10 +62,10 @@ class ZeroShotClassifierParameters(AnnotatorParameters):
         extra="key:label,inject",
     )
     multi_label: bool = Field(
-        False, description="Whether or not multiple candidate labels can be true."
+        False, description="Whether or not multiple candidate labels can be true.", extra="advanced"
     )
     multi_label_threshold: float = Field(
-        0.5, description="If multi-label you can set the threshold to make predictions."
+        0.5, description="If multi-label you can set the threshold to make predictions.", extra="advanced"
     )
     hypothesis_template: Optional[str] = Field(
         None,
@@ -73,7 +73,7 @@ class ZeroShotClassifierParameters(AnnotatorParameters):
                                                hypothesis. This template must include a {} for the
                                                candidate label to be inserted into the template. For
                                                example, the default template in english is
-                                               `\"This example is {}.\"`""",
+                                               `\"This example is {}.\"`""", extra="advanced"
     )
 
 
